@@ -10,28 +10,27 @@
 ###   compartment       path
 ###   ----------------  ------------------------------------
 ###   IGBLAST_ROOTS     <igblastr-cache>/igblast_roots
-###   LIVE_IGDATA       <igblastr-cache>/live_igdata
 ###   GERMLINE_DBS      <igblastr-cache>/germline_dbs
 ###   C_REGION_DBS      <igblastr-cache>/c_region_dbs
 ###   IMGT_LOCAL_STORE  <igblastr-cache>/store/IMGT-releases
 ###
 ### Always use the igblastr_cache() function implemented in this file to
-### obtain these paths.
+### construct these paths.
 
 IGBLAST_ROOTS    <- "IGBLAST_ROOTS"
-LIVE_IGDATA      <- "LIVE_IGDATA"
 GERMLINE_DBS     <- "GERMLINE_DBS"
 C_REGION_DBS     <- "C_REGION_DBS"
 IMGT_LOCAL_STORE <- "IMGT_LOCAL_STORE"
 
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### igblastr_cache()
 ###
 
-.IGBLASTR_CACHES <- c(IGBLAST_ROOTS, LIVE_IGDATA,
-                      GERMLINE_DBS, C_REGION_DBS, IMGT_LOCAL_STORE)
+.IGBLASTR_CACHES <- c(IGBLAST_ROOTS, GERMLINE_DBS,
+                      C_REGION_DBS, IMGT_LOCAL_STORE)
 
-### Returns **absolute** path to the cache compartment specified via 'which'.
+### Returns the path to the cache compartment specified via 'which'.
 igblastr_cache <- function(which=NULL)
 {
     path <- getOption("igblastr_cache", R_user_dir("igblastr", "cache"))
@@ -40,11 +39,10 @@ igblastr_cache <- function(which=NULL)
     stopifnot(isSingleNonWhiteString(which))
     switch(which,
         IGBLAST_ROOTS   =file.path(path, "igblast_roots"),
-        LIVE_IGDATA     =file.path(path, "live_igdata"),
         GERMLINE_DBS    =file.path(path, "germline_dbs"),
         C_REGION_DBS    =file.path(path, "c_region_dbs"),
         IMGT_LOCAL_STORE=file.path(path, "store", "IMGT-releases"),
-	stop(wmsg("'which' must be one of ",
+        stop(wmsg("'which' must be one of ",
                   paste0("\"", .IGBLASTR_CACHES, "\"", collapse=", ")))
     )
 }
