@@ -35,9 +35,9 @@ normalize_igblast_organism <- function(organism)
         stop(wmsg("'organism' must be a single (non-empty) string"))
     all_organisms <- list_igblast_organisms()
     organism <- tolower(organism)
-    if (!(organism %in% all_organisms)) {
-        in1string <- paste0("\"", all_organisms, "\"", collapse=", ")
-        stop(wmsg("'organism' must be one of ", in1string))
+    if (!(organism %in% list_igblast_organisms())) {
+        all_in_1string <- paste0("\"", all_organisms, "\"", collapse=", ")
+        stop(wmsg("'organism' must be one of ", all_in_1string))
     }
     organism
 }
@@ -75,7 +75,7 @@ normalize_igblast_organism <- function(organism)
                            silent=TRUE)
         if (!system_command_worked(raw_version))
             stop(wmsg("command '", cmdpath, " -version' failed"))
-	.IGBLAST_VERSION_cache[[cmdpath]] <- raw_version
+        .IGBLAST_VERSION_cache[[cmdpath]] <- raw_version
     }
     if (raw.version)
         return(raw_version)
@@ -103,7 +103,9 @@ igblast_build <- function(igblast_root=get_igblast_root())
 
 print.igblast_info <- function(x, ...)
 {
-    cat(named_list_as_pretty_keyvals(x), sep="\n")
+    x <- lapply(x, function(x) paste(x, collapse="; "))
+    x <- paste0(names(x), ": ", as.character(x))
+    cat(x, sep="\n")
 }
 
 igblast_info <- function(igblast_root=get_igblast_root())
